Imports Infragistics.Win
Imports Infragistics.Win.UltraWinGrid

Public Class Form1

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        With Me
            .MakeEnterCommitTheRow()
            .CreateDataSource()
            .CreateValueList()
            .AutoSizeGrid()
        End With
    End Sub

    Private Sub CreateDataSource()
        With Me
            Dim TestDataTable As New DataTable("TestDataTable")
            With TestDataTable
                With .Columns
                    .Add("Department")
                    .Add("Employee", GetType(Integer))
                End With
            End With

            Dim NewRow As DataRow = TestDataTable.NewRow
            NewRow("Department") = "Dept 1"
            NewRow("Employee") = 1
            TestDataTable.Rows.Add(NewRow)

            Dim NewRow2 As DataRow = TestDataTable.NewRow
            NewRow2("Department") = "Dept 2"
            NewRow2("Employee") = 2
            TestDataTable.Rows.Add(NewRow2)

            TestUltraGrid.DataSource = TestDataTable
        End With
    End Sub

    Private Sub CreateValueList()
        With Me
            Dim EmployeeValueList As New ValueList
            With EmployeeValueList.ValueListItems
                .Clear()
                .Add(1, "Doe Jane")
                .Add(2, "Smith Adam")
                .Add(3, "Walsh Kelly")
            End With

            With TestUltraGrid.DisplayLayout.Bands(0).Columns("Employee")
                .ValueList = EmployeeValueList
                .Style = UltraWinGrid.ColumnStyle.DropDownValidate
                .AutoCompleteMode = AutoCompleteMode.Suggest
            End With
        End With
    End Sub

    Private Sub AutoSizeGrid()
        With Me
            For Each MyCol As UltraGridColumn In .TestUltraGrid.DisplayLayout.Bands(0).Columns
                With MyCol
                    .PerformAutoResize(PerformAutoSizeType.AllRowsInBand, True)
                    .Width += 10
                End With
            Next
        End With
    End Sub

    Private Sub TestUltraGrid_CellDataError(ByVal sender As Object, ByVal e As Infragistics.Win.UltraWinGrid.CellDataErrorEventArgs) _
        Handles TestUltraGrid.CellDataError

        e.RaiseErrorEvent = False
        e.RestoreOriginalValue = False
        Console.WriteLine("CellDataError Event Fired")
    End Sub

    Private Sub TestUltraGrid_InitializeLayout(ByVal sender As System.Object, ByVal e As Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs) _
        Handles TestUltraGrid.InitializeLayout

        With e.Layout
            With .Override
                .SelectTypeCell = SelectType.None   ' disable selection forecolors for cells, rows,
                .SelectTypeCol = SelectType.None    ' and columns so you can still see the backcolor
                .SelectTypeRow = SelectType.None

                .SupportDataErrorInfo = SupportDataErrorInfo.RowsAndCells   ' allow the error provider
            End With
            .Bands(0).ColHeaderLines = 2
            .Rows.TemplateAddRow.Hidden = True  ' hide the template add row since adding rows programmatically
        End With
    End Sub

    Private Sub MakeEnterCommitTheRow()
        ' create a new mapping for a key in the specified grid
        Dim NewKeyActionMapping As GridKeyActionMapping

        For Each MyKeyActionMapping As GridKeyActionMapping In Me.TestUltraGrid.KeyActionMappings
            ' for each of the key mappings in the specified grid
            If MyKeyActionMapping.KeyCode = Keys.Enter Or MyKeyActionMapping.KeyCode = Keys.Return Then
                ' if it is for the enter or return key, delete the mapping
                MyKeyActionMapping.Dispose()
            End If
        Next

        ' add a new mapping for the enter key that will commit the row in the grid
        NewKeyActionMapping = New GridKeyActionMapping(Keys.Enter, UltraGridAction.CommitRow, 0, UltraGridState.Cell, Infragistics.Win.SpecialKeys.All, 0)
        Me.TestUltraGrid.KeyActionMappings.Add(NewKeyActionMapping)

        ' add a new mapping for the return key that will commit the row in the grid
        NewKeyActionMapping = New GridKeyActionMapping(Keys.Return, UltraGridAction.CommitRow, 0, UltraGridState.Cell, Infragistics.Win.SpecialKeys.All, 0)
        Me.TestUltraGrid.KeyActionMappings.Add(NewKeyActionMapping)
    End Sub

End Class
